@@ -20,8 +20,8 @@ describe 'tripleo::profile::base::cinder::backup::ceph' do
   shared_examples_for 'tripleo::profile::base::cinder::backup::ceph' do
     let(:pre_condition) do
       <<-EOF
-      class { '::tripleo::profile::base::cinder': step => #{params[:step]}, oslomsg_rpc_hosts => ['127.0.0.1'] }
-      class { '::tripleo::profile::base::cinder::backup': step => #{params[:step]} }
+      class { 'tripleo::profile::base::cinder': step => #{params[:step]}, oslomsg_rpc_hosts => ['127.0.0.1'] }
+      class { 'tripleo::profile::base::cinder::backup': step => #{params[:step]} }
       EOF
     end
 
